@@ -273,6 +273,7 @@ main(int  argc,				/* I - Number of command-line args */
 		*pstops_options,	/* Options for pstops filter */
 		*pstops_end;		/* End of pstops filter option */
   const char	*cups_serverbin;	/* CUPS_SERVERBIN environment variable */
+  const char	*content_type;		/* CONTENT_TYPE environment variable */
 #if defined(HAVE_SIGACTION) && !defined(HAVE_SIGSET)
   struct sigaction action;		/* Actions for POSIX signals */
 #endif /* HAVE_SIGACTION && !HAVE_SIGSET */
@@ -438,6 +439,7 @@ main(int  argc,				/* I - Number of command-line args */
   * Build the command-line for the pdftops or gs filter...
   */
 
+  content_type = getenv("CONTENT_TYPE");
   if (renderer == PDFTOPS)
   {
     pdf_argv[0] = (char *)"pdftops";
@@ -630,7 +632,9 @@ main(int  argc,				/* I - Number of command-line args */
       *  which contain pages of different sizes can be printed correctly
       */
 
-      pdf_argv[pdf_argc++] = (char *)"-origpagesizes";
+      /* Only do this for unprocessed PDF files */
+      if (content_type && !strstr (content_type, "/vnd.cups-"))
+        pdf_argv[pdf_argc++] = (char *)"-origpagesizes";
     }
 #endif /* HAVE_POPPLER_PDFTOPS_WITH_ORIGPAGESIZES */
     else if (renderer == ACROREAD)
@@ -640,7 +644,9 @@ main(int  argc,				/* I - Number of command-line args */
       * which contain pages of different sizes can be printed correctly
       */
      
-      pdf_argv[pdf_argc++] = (char *)"-choosePaperByPDFPageSize";
+      /* Only do this for unprocessed PDF files */
+      if (content_type && !strstr (content_type, "/vnd.cups-"))
+        pdf_argv[pdf_argc++] = (char *)"-choosePaperByPDFPageSize";
     }
 
    /*
